/*
This is a Check Printing Form designed for printing with
the DCPRINT system.  All Check data is passed to the
function PrintCheck() in a multi-dimensional array.
*/

#INCLUDE "dcprint.ch"
#INCLUDE "dcdialog.ch"

#define CHECK_DATE                     1
#define CHECK_PAYTO                    2
#define CHECK_NUMBER                   3

#define CHECK_AMOUNT                   4
#define CHECK_MEMO                     5
#define CHECK_PAYEE_NAME               6
#define CHECK_PAYEE_ADDRESS1           7
#define CHECK_PAYEE_ADDRESS2           8
#define CHECK_PAYEE_CITY               9
#define CHECK_PAYEE_STATE             10
#define CHECK_PAYEE_ZIP               11
#define CHECK_PAYEE_COUNTRY           12

#define CHECK_PAYER_NAME              13
#define CHECK_PAYER_ADDRESS1          14
#define CHECK_PAYER_ADDRESS2          15
#define CHECK_PAYER_ACCOUNT_NO        16
#define CHECK_PAYER_SIGNATURE         17

#define CHECK_BANK_NAME               18
#define CHECK_BANK_ADDRESS1           19
#define CHECK_BANK_ADDRESS2           20
#define CHECK_BANK_BANK_NO            21
#define CHECK_BANK_TRANSIT_NO         22

#define CHECK_VOUCHER_LINE1           23
#define CHECK_VOUCHER_LINE2           24
#define CHECK_VOUCHER_LINE3           25
#define CHECK_VOUCHER_LINE4           26
#define CHECK_VOUCHER_LINE5           27
#define CHECK_VOUCHER_LINE6           28
#define CHECK_VOUCHER_LINE7           29
#define CHECK_VOUCHER_LINE8           30
#define CHECK_VOUCHER_LINE9           31

#define CHECK_NUMBER_POS              32
#define CHECK_DATE_POS                33
#define CHECK_BANK_BANK_NO_POS        34
#define CHECK_PAYTO_POS               35
#define CHECK_PAYEE_NAME_POS          36
#define CHECK_AMOUNT_NUM_POS          37
#define CHECK_AMOUNT_WORDS_POS        38
#define CHECK_MEMO_POS                39
#define CHECK_SIGNATURE_POS           40
#define CHECK_PAYER_POS               41
#define CHECK_BANK_POS                42
#define CHECK_MICR_CHECK_NO_POS       43
#define CHECK_MICR_TRANSIT_NO_POS     44
#define CHECK_MICR_ACCOUNT_NO_POS     45

#define CHECK_VOUCHER1_POS            46
#define CHECK_VOUCHER2_POS            47

#define CHECK_ARRAY_SIZE              47

MEMVAR aCheck

FUNCTION Main()

LOCAL i, lStatus, GetList[0], GetOptions, aData[CHECK_ARRAY_SIZE], ;
      oTabPage1, oTabPage2, oTabPage3, oTabPage4, oTabPage5, lPreview := .t.

IF File('CHECKS.XPF')

  PRIVATE aCheck
  RESTORE FROM CHECKS.XPF
  aData := M->aCheck

ELSE

  aData[CHECK_NUMBER]               := Pad("16401732",10)
  aData[CHECK_DATE]                 := Date()
  aData[CHECK_PAYTO]                := Pad('Roger J. Donnay',40)
  aData[CHECK_AMOUNT]               := 0
  aData[CHECK_PAYEE_NAME]           := Pad('Donnay Software Designs',40)
  aData[CHECK_PAYEE_ADDRESS1]       := Pad('1632 Riverstone Ln #301',40)
  aData[CHECK_PAYEE_ADDRESS2]       := Space(40)
  aData[CHECK_PAYEE_CITY]           := Pad('Boise',30)
  aData[CHECK_PAYEE_STATE]          := Pad('ID',15)
  aData[CHECK_PAYEE_ZIP]            := Pad('83706',10)
  aData[CHECK_PAYEE_COUNTRY]        := Pad('U.S.A.',20)
  aData[CHECK_MEMO]                 := Space(60)

  aData[CHECK_PAYER_NAME]           := Pad('BEAU SERVICE CORP',40)
  aData[CHECK_PAYER_ADDRESS1]       := Pad('54-11 QUEENS BLVD',40)
  aData[CHECK_PAYER_ADDRESS2]       := Pad('WOODSIDE NY, 11377',40)
  aData[CHECK_PAYER_ACCOUNT_NO]     := Pad('6901152630',12)
  aData[CHECK_PAYER_SIGNATURE]      := Pad('SIGNATURE.BMP',50)

  aData[CHECK_BANK_BANK_NO]         := Pad('50-1063/214',15)
  aData[CHECK_BANK_TRANSIT_NO]      := Pad("021410637",12)
  aData[CHECK_BANK_NAME]            := Pad("THE BANK OF NEW YORK  6H15",40)
  aData[CHECK_BANK_ADDRESS1]        := Pad("54-12 48TH ST",40)
  aData[CHECK_BANK_ADDRESS2]        := Pad("MASPETH, N.Y. 11378",40)

  FOR i := 1 TO 9
    aData[CHECK_VOUCHER_LINE1+i-1]  := Space(80)
  NEXT

  aData[CHECK_NUMBER_POS]           := {  3.0, 65.0 }
  aData[CHECK_DATE_POS]             := {  5.0, 62.0 }
  aData[CHECK_PAYTO_POS]            := {  7.5, 15.0 }
  aData[CHECK_PAYEE_NAME_POS]       := {  0.0,  0.0 }
  aData[CHECK_AMOUNT_NUM_POS]       := {  7.5, 75.0 }
  aData[CHECK_AMOUNT_WORDS_POS]     := {  9.8, 15.0 }
  aData[CHECK_MEMO_POS]             := {  0.0,  0.0 }
  aData[CHECK_SIGNATURE_POS]        := { 16.0, 48.0 }
  aData[CHECK_PAYER_POS]            := {  3.0,  6.0 }
  aData[CHECK_BANK_POS]             := { 12.0,  6.0 }
  aData[CHECK_BANK_BANK_NO_POS]     := {  5.0, 71.0 }
  aData[CHECK_MICR_CHECK_NO_POS]    := { 19.0,  3.0 }
  aData[CHECK_MICR_TRANSIT_NO_POS]  := { 19.0, 18.0 }
  aData[CHECK_MICR_ACCOUNT_NO_POS]  := { 19.0, 33.0 }
  aData[CHECK_VOUCHER1_POS]         := { 24.0,  1.0 }
  aData[CHECK_VOUCHER2_POS]         := { 45.0,  1.0 }

ENDIF

FOR i := 1 TO 9
  aData[CHECK_VOUCHER_LINE1+i-1] := Pad(aData[CHECK_VOUCHER_LINE1+i-1],80)
NEXT

@ 0,0 DCTABPAGE oTabPage1 CAPTION 'Payee' SIZE 100,15
@ 0,0 DCTABPAGE oTabPage2 RELATIVE oTabPage1 CAPTION 'Bank'
@ 0,0 DCTABPAGE oTabPage3 RELATIVE oTabPage2 CAPTION 'Payer'
@ 0,0 DCTABPAGE oTabPage4 RELATIVE oTabPage3 CAPTION 'Voucher'
@ 0,0 DCTABPAGE oTabPage5 RELATIVE oTabPage4 CAPTION 'Coords'

DCSETPARENT TO oTabPage1
@  2,5 DCSAY 'Check #' GET aData[CHECK_NUMBER]
@  3,5 DCSAY 'Date' GET aData[CHECK_DATE] POPUP {|d|DC_PopDate(d)}
@  4,5 DCSAY 'Pay to' GET aData[CHECK_PAYTO]
@  5,5 DCSAY 'Amount' GET aData[CHECK_AMOUNT] PICT '999999.99'
@  6,5 DCSAY 'Memo' GET aData[CHECK_MEMO] GETSIZE 50
@  7,5 DCSAY 'Name' GET aData[CHECK_PAYEE_NAME]
@  8,5 DCSAY 'Address 1' GET aData[CHECK_PAYEE_ADDRESS1]
@  9,5 DCSAY 'Address 2' GET aData[CHECK_PAYEE_ADDRESS2]
@ 10,5 DCSAY 'City' GET aData[CHECK_PAYEE_CITY]
@ 11,5 DCSAY 'State' GET aData[CHECK_PAYEE_STATE]
@ 12,5 DCSAY 'Zip' GET aData[CHECK_PAYEE_ZIP]
@ 13,5 DCSAY 'Country' GET aData[CHECK_PAYEE_COUNTRY]

DCSETPARENT TO oTabPage2
@ 2,5 DCSAY 'Bank Number' GET aData[CHECK_BANK_BANK_NO]
@ 3,5 DCSAY 'Transit Number' GET aData[CHECK_BANK_TRANSIT_NO]
@ 4,5 DCSAY 'Account Number' GET aData[CHECK_PAYER_ACCOUNT_NO]
@ 5,5 DCSAY 'Bank Name' GET aData[CHECK_BANK_NAME]
@ 6,5 DCSAY 'Bank Address 1' GET aData[CHECK_BANK_ADDRESS1]
@ 7,5 DCSAY 'Bank Address 2' GET aData[CHECK_BANK_ADDRESS2]

DCSETPARENT TO oTabPage3
@ 2,5 DCSAY 'Payer Name' GET aData[CHECK_PAYER_NAME]
@ 3,5 DCSAY 'Payer Address 1' GET aData[CHECK_PAYER_ADDRESS1]
@ 4,5 DCSAY 'Payer Address 2' GET aData[CHECK_PAYER_ADDRESS2]
@ 4,5 DCSAY 'Payer Signature File' GET aData[CHECK_PAYER_SIGNATURE]

DCSETPARENT TO oTabPage4
@  2,1 DCSAY 'Line 1' GET aData[CHECK_VOUCHER_LINE1] SAYSIZE 0
@  3,1 DCSAY 'Line 2' GET aData[CHECK_VOUCHER_LINE2] SAYSIZE 0
@  4,1 DCSAY 'Line 3' GET aData[CHECK_VOUCHER_LINE3] SAYSIZE 0
@  5,1 DCSAY 'Line 4' GET aData[CHECK_VOUCHER_LINE4] SAYSIZE 0
@  6,1 DCSAY 'Line 5' GET aData[CHECK_VOUCHER_LINE5] SAYSIZE 0
@  7,1 DCSAY 'Line 6' GET aData[CHECK_VOUCHER_LINE6] SAYSIZE 0
@  8,1 DCSAY 'Line 7' GET aData[CHECK_VOUCHER_LINE7] SAYSIZE 0
@  9,1 DCSAY 'Line 8' GET aData[CHECK_VOUCHER_LINE8] SAYSIZE 0
@ 10,1 DCSAY 'Line 9' GET aData[CHECK_VOUCHER_LINE9] SAYSIZE 0

DCSETPARENT TO oTabPage5
@ 2,25  DCSAY 'Print Coordinates:' COLOR GRA_CLR_BLUE SAYSIZE 0
@ 3,25  DCSAY 'Row' COLOR GRA_CLR_BLUE SAYSIZE 0
@ 3,31 DCSAY 'Col' COLOR GRA_CLR_BLUE SAYSIZE 0

@ 5,10 DCSAY 'Check Number'
@ 5,25 DCGET aData[CHECK_NUMBER_POS,1] PICT '99.9'
@ 5,31 DCGET aData[CHECK_NUMBER_POS,2] PICT '99.9'

@ 6,10 DCSAY 'Date'
@ 6,25 DCGET aData[CHECK_DATE_POS,1] PICT '99.9'
@ 6,31 DCGET aData[CHECK_DATE_POS,2] PICT '99.9'

@ 7,10 DCSAY 'Pay To'
@ 7,25 DCGET aData[CHECK_PAYTO_POS,1] PICT '99.9'
@ 7,31 DCGET aData[CHECK_PAYTO_POS,2] PICT '99.9'

@ 8,10 DCSAY 'Name/Address'
@ 8,25 DCGET aData[CHECK_PAYEE_NAME_POS,1] PICT '99.9'
@ 8,31 DCGET aData[CHECK_PAYEE_NAME_POS,2] PICT '99.9'

@ 9,10 DCSAY 'Amount (Num)'
@ 9,25 DCGET aData[CHECK_AMOUNT_NUM_POS,1] PICT '99.9'
@ 9,31 DCGET aData[CHECK_AMOUNT_NUM_POS,2] PICT '99.9'

@10,10 DCSAY 'Amount (Words)'
@10,25 DCGET aData[CHECK_AMOUNT_WORDS_POS,1] PICT '99.9'
@10,31 DCGET aData[CHECK_AMOUNT_WORDS_POS,2] PICT '99.9'

@11,10 DCSAY 'Memo'
@11,25 DCGET aData[CHECK_MEMO_POS,1] PICT '99.9'
@11,31 DCGET aData[CHECK_MEMO_POS,2] PICT '99.9'

@12,10 DCSAY 'Signature'
@12,25 DCGET aData[CHECK_SIGNATURE_POS,1] PICT '99.9'
@12,31 DCGET aData[CHECK_SIGNATURE_POS,2] PICT '99.9'

@ 2,55  DCSAY 'Print Coordinates:' COLOR GRA_CLR_BLUE SAYSIZE 0
@ 3,55  DCSAY 'Row' COLOR GRA_CLR_BLUE SAYSIZE 0
@ 3,61 DCSAY 'Col' COLOR GRA_CLR_BLUE SAYSIZE 0

@ 5,40 DCSAY 'Payer Name'
@ 5,55 DCGET aData[CHECK_PAYER_POS,1] PICT '99.9'
@ 5,61 DCGET aData[CHECK_PAYER_POS,2] PICT '99.9'

@ 6,40 DCSAY 'Bank Name'
@ 6,55 DCGET aData[CHECK_BANK_POS,1] PICT '99.9'
@ 6,61 DCGET aData[CHECK_BANK_POS,2] PICT '99.9'

@ 7,40 DCSAY 'Micr Check #'
@ 7,55 DCGET aData[CHECK_MICR_CHECK_NO_POS,1] PICT '99.9'
@ 7,61 DCGET aData[CHECK_MICR_CHECK_NO_POS,2] PICT '99.9'

@ 8,40 DCSAY 'Micr Transit #'
@ 8,55 DCGET aData[CHECK_MICR_TRANSIT_NO_POS,1] PICT '99.9'
@ 8,61 DCGET aData[CHECK_MICR_TRANSIT_NO_POS,2] PICT '99.9'

@ 9,40 DCSAY 'Micr Account #'
@ 9,55 DCGET aData[CHECK_MICR_ACCOUNT_NO_POS,1] PICT '99.9'
@ 9,61 DCGET aData[CHECK_MICR_ACCOUNT_NO_POS,2] PICT '99.9'

@10,40 DCSAY 'Voucher 1'
@10,55 DCGET aData[CHECK_VOUCHER1_POS,1] PICT '99.9'
@10,61 DCGET aData[CHECK_VOUCHER1_POS,2] PICT '99.9'

@11,40 DCSAY 'Voucher 2'
@11,55 DCGET aData[CHECK_VOUCHER2_POS,1] PICT '99.9'
@11,61 DCGET aData[CHECK_VOUCHER2_POS,2] PICT '99.9'

@12,40 DCSAY 'Bank Number'
@12,55 DCGET aData[CHECK_BANK_BANK_NO_POS,1] PICT '99.9'
@12,61 DCGET aData[CHECK_BANK_BANK_NO_POS,2] PICT '99.9'


DCSETPARENT TO

@ 16,1 DCPUSHBUTTON CAPTION 'Exit' SIZE 9,1.2 ;
       ACTION {||DC_ReadGuiEvent(DCGUI_EXIT_OK,GetList)}

@ 16,12 DCPUSHBUTTON CAPTION 'Print' SIZE 9,1.2 ;
       ACTION {||PrintCheck(aData,lPreview)}

@ 16,24 DCCHECKBOX lPreview PROMPT 'Preview'

DCGETOPTIONS SAYWIDTH 100 SAYRIGHT

DCREAD GUI FIT OPTIONS GetOptions ;
   TITLE 'Create and Print a Check' ;
   TO lStatus SETAPPWINDOW

IF lStatus
  aCheck := aData
  SAVE ALL LIKE aCheck TO CHECKS.XPF
ENDIF

RETURN nil

* -------------------

STATIC FUNCTION PrintCheck( aData, lPreview )

LOCAL oPrinter, nOffset, i, cString, nMicrOffset := 1.25

DCPRINT ON ;
  _PREVIEW lPreview ;
  TO oPrinter ;
  HIDE ;
  NONSTOP

IF Valtype(oPrinter) # 'O' .OR. !oPrinter:lActive
  RETURN .f.
ENDIF

DCPRINT FONT '12.Arial'

// Print Check Number
@ aData[CHECK_NUMBER_POS,1], aData[CHECK_NUMBER_POS,2] ;
  DCPRINT SAY Trim(DC_XtoC(aData[CHECK_NUMBER])) FONT '16.Arial Bold'

// Print Date
@ aData[CHECK_DATE_POS,1], aData[CHECK_DATE_POS,2] ;
  DCPRINT SAY DtoC(aData[CHECK_DATE]) FONT '8.Lucida Console'

// Print Bank Number
IF !Empty(aData[CHECK_BANK_BANK_NO])
  @ aData[CHECK_BANK_BANK_NO_POS,1], aData[CHECK_BANK_BANK_NO_POS,2] ;
      DCPRINT SAY Trim(aData[CHECK_BANK_BANK_NO]) FONT '8.Lucida Console'
ENDIF

// Print Payer Name and Address
IF !Empty(aData[CHECK_PAYER_NAME])
  @aData[CHECK_PAYER_POS,1], aData[CHECK_PAYER_POS,2] ;
      DCPRINT SAY Trim(aData[CHECK_PAYER_NAME]) FONT '16.Arial Bold'
ENDIF
IF !Empty(aData[CHECK_PAYER_ADDRESS1])
  @aData[CHECK_PAYER_POS,1]+.8, aData[CHECK_PAYER_POS,2] ;
      DCPRINT SAY Trim(aData[CHECK_PAYER_ADDRESS1]) FONT '7.Lucida Console'
ENDIF
IF !Empty(aData[CHECK_PAYER_ADDRESS2])
  @aData[CHECK_PAYER_POS,1]+1.4, aData[CHECK_PAYER_POS,2] ;
      DCPRINT SAY Trim(aData[CHECK_PAYER_ADDRESS2]) FONT '7.Lucida Console'
ENDIF

// Print Bank Name and Address
IF !Empty(aData[CHECK_BANK_NAME])
  @aData[CHECK_BANK_POS,1], aData[CHECK_BANK_POS,2] ;
      DCPRINT SAY Trim(aData[CHECK_BANK_NAME]) FONT '10.Courier New'
ENDIF
IF !Empty(aData[CHECK_BANK_ADDRESS1])
  @aData[CHECK_BANK_POS,1]+.8, aData[CHECK_BANK_POS,2] ;
      DCPRINT SAY Trim(aData[CHECK_BANK_ADDRESS1]) FONT '7.Lucida Console'
ENDIF
IF !Empty(aData[CHECK_BANK_ADDRESS2])
  @aData[CHECK_BANK_POS,1]+1.4, aData[CHECK_BANK_POS,2] ;
      DCPRINT SAY Trim(aData[CHECK_BANK_ADDRESS2]) FONT '7.Lucida Console'
ENDIF

// Print PayTo
@ aData[CHECK_PAYTO_POS,1], aData[CHECK_PAYTO_POS,2]-1 ;
    DCPRINT SAY 'PAY TO THE ORDER OF' ALIGN DCPRINT_ALIGN_RIGHT ;
    FONT '8.Lucida Console'

@ aData[CHECK_PAYTO_POS,1], aData[CHECK_PAYTO_POS,2] ;
    DCPRINT SAY Trim(aData[CHECK_PAYTO])

@ aData[CHECK_PAYTO_POS,1]+1, aData[CHECK_PAYTO_POS,2], ;
  aData[CHECK_PAYTO_POS,1]+1, aData[CHECK_PAYTO_POS,2] + 35;
    DCPRINT LINE

// Print Amount (numeric)
@ aData[CHECK_AMOUNT_NUM_POS,1]+1, aData[CHECK_AMOUNT_NUM_POS,2]-20, ;
  aData[CHECK_AMOUNT_NUM_POS,1]+1, aData[CHECK_AMOUNT_NUM_POS,2] ;
    DCPRINT LINE

@ aData[CHECK_AMOUNT_NUM_POS,1], aData[CHECK_AMOUNT_NUM_POS,2] ;
  DCPRINT SAY aData[CHECK_AMOUNT] PICT '$999,999,999.99' ALIGN DCPRINT_ALIGN_RIGHT

// Print Amount (in Words)
@ aData[CHECK_AMOUNT_WORDS_POS,1], aData[CHECK_AMOUNT_WORDS_POS,2]-1 ;
    DCPRINT SAY 'AMOUNT' ALIGN DCPRINT_ALIGN_RIGHT ;
    FONT '10.Lucida Console'

@ aData[CHECK_AMOUNT_WORDS_POS,1], aData[CHECK_AMOUNT_WORDS_POS,2] ;
  DCPRINT SAY NumToWords(aData[CHECK_AMOUNT])

@ aData[CHECK_AMOUNT_WORDS_POS,1]+1, aData[CHECK_AMOUNT_WORDS_POS,2], ;
  aData[CHECK_AMOUNT_WORDS_POS,1]+1, aData[CHECK_AMOUNT_NUM_POS,2]  ;
    DCPRINT LINE

// Print Memo
IF !Empty(aData[CHECK_MEMO])
  @ aData[CHECK_MEMO_POS,1], aData[CHECK_MEMO_POS,2] ;
    DCPRINT SAY Trim(aData[CHECK_MEMO])
ENDIF

// Print Payee Address Lines
DCPRINT FONT '11.Courier New'
IF !Empty(aData[CHECK_PAYEE_NAME])
  @ aData[CHECK_PAYEE_NAME_POS,1], aData[CHECK_PAYEE_NAME_POS,2] ;
    DCPRINT SAY Trim(aData[CHECK_PAYEE_NAME])
ENDIF
IF !Empty(aData[CHECK_PAYEE_ADDRESS1])
  @ aData[CHECK_PAYEE_NAME_POS,1]+1, aData[CHECK_PAYEE_NAME_POS,2] ;
    DCPRINT SAY Trim(aData[CHECK_BANK_ADDRESS1])
ENDIF
nOffset := 0
IF !Empty(aData[CHECK_PAYEE_ADDRESS2])
  @ aData[CHECK_PAYEE_NAME_POS,1]+2, aData[CHECK_PAYEE_NAME_POS,2] ;
    DCPRINT SAY Trim(aData[CHECK_PAYEE_ADDRESS2])
  nOffset := 1
ENDIF
IF !Empty(aData[CHECK_PAYEE_STATE])
  @ aData[CHECK_PAYEE_NAME_POS,1]+2+nOffset, aData[CHECK_PAYEE_NAME_POS,2] ;
    DCPRINT SAY Trim(aData[CHECK_PAYEE_CITY]) + ', ' + ;
    Trim(aData[CHECK_PAYEE_STATE]) + ' ' + Trim(aData[CHECK_PAYEE_COUNTRY])
ENDIF

DCPRINT FONT '12.MICRSSK'
// Print MICR Check Number
cString := 'C' + Trim(aData[CHECK_NUMBER]) + 'C'
FOR i := 1 TO Len(cString)
  @ aData[CHECK_MICR_CHECK_NO_POS,1], aData[CHECK_MICR_CHECK_NO_POS,2] + (i*nMicrOffset) ;
      DCPRINT SAY cString[i]
NEXT

// Print MICR Transit Number
cString := 'A' + Trim(aData[CHECK_BANK_TRANSIT_NO]) + 'A'
FOR i := 1 TO Len(cString)
  @ aData[CHECK_MICR_TRANSIT_NO_POS,1], aData[CHECK_MICR_TRANSIT_NO_POS,2] + (i*nMicrOffset) ;
    DCPRINT SAY cString[i]
NEXT

// Print MICR Account Number
cString := 'C' + Trim(aData[CHECK_PAYER_ACCOUNT_NO]) + 'C'
FOR i := 1 TO Len(cString)
  @ aData[CHECK_MICR_ACCOUNT_NO_POS,1], aData[CHECK_MICR_ACCOUNT_NO_POS,2] + (i*nMicrOffset) ;
      DCPRINT SAY cString[i]
NEXT

DCPRINT FONT '12.Arial'

// Print Signature
IF !Empty(aData[CHECK_PAYER_SIGNATURE])
  @ aData[CHECK_SIGNATURE_POS,1], aData[CHECK_SIGNATURE_POS,2], ;
    aData[CHECK_SIGNATURE_POS,1]+1, aData[CHECK_SIGNATURE_POS,2]+25 ;
    DCPRINT BITMAP Alltrim(aData[CHECK_PAYER_SIGNATURE])
ENDIF

@ aData[CHECK_SIGNATURE_POS,1]+2, aData[CHECK_SIGNATURE_POS,2], ;
  aData[CHECK_SIGNATURE_POS,1]+2, aData[CHECK_SIGNATURE_POS,2] + 25;
    DCPRINT LINE

// Print Vouchers
IF !Empty(aData[CHECK_VOUCHER_LINE1])
  @ aData[CHECK_VOUCHER1_POS,1], aData[CHECK_DATE_POS,2] ;
    DCPRINT SAY DtoC(aData[CHECK_DATE]) FONT '12.Arial'

  DCPRINT FONT '11.Lucida Console'
  FOR i := 1 TO 9
    @ aData[CHECK_VOUCHER1_POS,1]+i+1, aData[CHECK_VOUCHER1_POS,2] ;
      DCPRINT SAY Strtran(Trim(aData[CHECK_VOUCHER_LINE1+i-1]),' ',Chr(255))
  NEXT

  @ aData[CHECK_VOUCHER2_POS,1], aData[CHECK_DATE_POS,2] ;
    DCPRINT SAY DtoC(aData[CHECK_DATE]) FONT '12.Arial'

  FOR i := 1 TO 9
    @ aData[CHECK_VOUCHER2_POS,1]+i+1, aData[CHECK_VOUCHER2_POS,2] ;
      DCPRINT SAY Strtran(Trim(aData[CHECK_VOUCHER_LINE1+i-1]),' ',Chr(255))
  NEXT
ENDIF

DCPRINT OFF

RETURN nil

* -------------------

FUNCTION NumToWords( nAmount )

LOCAL cResult, cCents, cAmount := Str(nAmount)

cCents := Substr(cAmount,At('.',cAmount)+1)
cResult = _NumToWords( nAmount )
cResult += ' and ' + cCents + '/100 Dollars***'

RETURN cResult

* -------------------

FUNCTION _NumToWords( nAmount )

LOCAL nTemp, cResult := " ", nQualNo
LOCAL nDiv := 10 ^ ( Int( sol10(nAmount) / 3 ) * 3 )
LOCAL ones  := { "",     " One",   " Two",   " Three", " Four", " Five",  ;
                 " Six", " Seven", " Eight", " Nine"                      ;
               }

LOCAL teens := { " Ten",      " Eleven",    " Twelve",   ;
                 " Thirteen", " Fourteen",  " Fifteen",  ;
                 " Sixteen",  " Seventeen", " Eighteen", ;
                 " Nineteen"                             ;
               }

LOCAL tens  :=  { "", "", " Twenty", " Thirty", " Forty", " Fifty", ;
                  " Sixty", " Seventy", " Eighty", " Ninety"  }

LOCAL qualifiers := { "", " Thousand", " Million", " Billion", " Trillion" }

nTemp   := int(nAmount % nDiv)
nAmount := int(nAmount / nDiv)
nQualNo := int( sol10( nDiv ) / 3 ) + 1
cResult += grp_to_words(nAmount, qualifiers[ nQualNo ], ones, teens, tens )

IF nTemp > (nDiv /= 1000) .and. (nDiv > 1)
  cResult += _NumToWords( nTemp, nDiv )
ELSE
  cResult += grp_to_words(nTemp, "", ones, teens, tens)
ENDIF

RETURN LTrim(cResult)

* -----------

STATIC FUNCTION grp_to_words( nGrp, sQual, ones, teens, tens )

LOCAL cResult := "", nTemp

nTemp   := int(nGrp % 100)
nGrp    := int(nGrp / 100)

cResult += ones[ nGrp + 1 ] + iif( nGrp > 0, " Hundred", "")

DO CASE
  CASE nTemp > 19
    cResult += tens[ int( nTemp / 10 ) + 1 ]
    cResult += ones[ int( nTemp % 10 ) + 1 ]
  CASE nTemp < 20 .and. nTemp > 9
    cResult += teens[ int( nTemp % 10 ) + 1 ]
  CASE nTemp < 10 .and. nTemp > 0
    cResult += ones[ int( nTemp) + 1 ]
ENDCASE

RETURN cResult + sQual

* ----------

STATIC FUNCTION sol10( nNumber )

LOCAL sTemp := LTrim( Str( Int(nNumber) ) )

RETURN len(sTemp) - 1

* ------------

PROC appsys
RETURN


